@@ -126,12 +126,9 @@ NewFormWidget::NewFormWidget(QDesignerFormEditorInterface *core, QWidget *parent
     QDesignerNewFormWidgetInterface(parentWidget),
     m_core(core),
     m_ui(new Ui::NewFormWidget),
-    m_currentItem(0),
-    m_acceptedItem(0)
+    m_currentItem(nullptr),
+    m_acceptedItem(nullptr)
 {
-    typedef void (QComboBox::*QComboIntSignal)(int);
-    typedef QList<qdesigner_internal::DeviceProfile> DeviceProfileList;
-
     m_ui->setupUi(this);
     m_ui->treeWidget->setItemDelegate(new qdesigner_internal::SheetDelegate(m_ui->treeWidget, this));
     m_ui->treeWidget->header()->hide();
@@ -150,7 +147,7 @@ NewFormWidget::NewFormWidget(QDesignerFormEditorInterface *core, QWidget *parent
 
     // Resource templates
     const QString formTemplate = settings.formTemplate();
-    QTreeWidgetItem *selectedItem = 0;
+    QTreeWidgetItem *selectedItem = nullptr;
     loadFrom(templatePath, true, uiExtension, formTemplate, selectedItem);
     // Additional template paths
     const QStringList formTemplatePaths = settings.formTemplatePaths();
@@ -166,7 +163,7 @@ NewFormWidget::NewFormWidget(QDesignerFormEditorInterface *core, QWidget *parent
     }
 
     // Still no selection - default to first item
-    if (selectedItem == 0 && m_ui->treeWidget->topLevelItemCount() != 0) {
+    if (selectedItem == nullptr && m_ui->treeWidget->topLevelItemCount() != 0) {
         QTreeWidgetItem *firstTopLevel = m_ui->treeWidget->topLevelItem(0);
         if (firstTopLevel->childCount() > 0)
             selectedItem = firstTopLevel->child(0);
@@ -175,20 +172,20 @@ NewFormWidget::NewFormWidget(QDesignerFormEditorInterface *core, QWidget *parent
     // Open parent, select and make visible
     if (selectedItem) {
         m_ui->treeWidget->setCurrentItem(selectedItem);
-        m_ui->treeWidget->setItemSelected(selectedItem, true);
+        selectedItem->setSelected(true);
         m_ui->treeWidget->scrollToItem(selectedItem->parent());
     }
     // Fill profile combo
     m_deviceProfiles = settings.deviceProfiles();
     m_ui->profileComboBox->addItem(tr("None"));
-    connect(m_ui->profileComboBox, static_cast<QComboIntSignal>(&QComboBox::currentIndexChanged),
+    connect(m_ui->profileComboBox,
+            QOverload<int>::of(&QComboBox::currentIndexChanged),
             this, &NewFormWidget::slotDeviceProfileIndexChanged);
-    if (m_deviceProfiles.empty()) {
+    if (m_deviceProfiles.isEmpty()) {
         m_ui->profileComboBox->setEnabled(false);
     } else {
-        const DeviceProfileList::const_iterator dcend = m_deviceProfiles.constEnd();
-        for (DeviceProfileList::const_iterator it = m_deviceProfiles.constBegin(); it != dcend; ++it)
-            m_ui->profileComboBox->addItem(it->name());
+        for (const auto &deviceProfile : qAsConst(m_deviceProfiles))
+            m_ui->profileComboBox->addItem(deviceProfile.name());
         const int ci = settings.currentDeviceProfileIndex();
         if (ci >= 0)
             m_ui->profileComboBox->setCurrentIndex(ci + profileComboIndexOffset);
@@ -303,7 +300,7 @@ QImage NewFormWidget::grabForm(QDesignerFormEditorInterface *core,
     if (!workingDir.isEmpty())
         formBuilder.setWorkingDirectory(workingDir);
 
-    QWidget *widget = formBuilder.load(&file, 0);
+    QWidget *widget = formBuilder.load(&file, nullptr);
     if (!widget)
         return QImage();
 
@@ -436,7 +433,7 @@ void NewFormWidget::loadFrom(const QString &path, bool resourceFile, const QStri
 
         QTreeWidgetItem *item = new QTreeWidgetItem(root);
         const QString text = it->baseName().replace(underscore, blank);
-        if (selectedItemFound == 0 && text == selectedItem)
+        if (selectedItemFound == nullptr && text == selectedItem)
             selectedItemFound = item;
         item->setText(0, text);
         item->setData(0, TemplateNameRole, it->absoluteFilePath());
@@ -446,7 +443,7 @@ void NewFormWidget::loadFrom(const QString &path, bool resourceFile, const QStri
 void NewFormWidget::loadFrom(const QString &title, const QStringList &nameList,
                        const QString &selectedItem, QTreeWidgetItem *&selectedItemFound)
 {
-    if (nameList.empty())
+    if (nameList.isEmpty())
         return;
     QTreeWidgetItem *root = new QTreeWidgetItem(m_ui->treeWidget);
     root->setFlags(root->flags() & ~Qt::ItemIsSelectable);
@@ -456,7 +453,7 @@ void NewFormWidget::loadFrom(const QString &title, const QStringList &nameList,
         const QString text = *it;
         QTreeWidgetItem *item = new QTreeWidgetItem(root);
         item->setText(0, text);
-        if (selectedItemFound == 0 && text == selectedItem)
+        if (selectedItemFound == nullptr && text == selectedItem)
             selectedItemFound = item;
         item->setData(0, ClassNameRole, *it);
     }
@@ -465,7 +462,7 @@ void NewFormWidget::loadFrom(const QString &title, const QStringList &nameList,
 void NewFormWidget::on_treeWidget_itemPressed(QTreeWidgetItem *item)
 {
     if (item && !item->parent())
-        m_ui->treeWidget->setItemExpanded(item, !m_ui->treeWidget->isItemExpanded(item));
+        item->setExpanded(!item->isExpanded());
 }
 
 QSize NewFormWidget::templateSize() const
@@ -545,12 +542,12 @@ qdesigner_internal::DeviceProfile NewFormWidget::currentDeviceProfile() const
 
 bool NewFormWidget::hasCurrentTemplate() const
 {
-    return m_currentItem != 0;
+    return m_currentItem != nullptr;
 }
 
 QString NewFormWidget::currentTemplateI(QString *ptrToErrorMessage)
 {
-    if (m_currentItem == 0) {
+    if (m_currentItem == nullptr) {
         *ptrToErrorMessage = tr("Internal error: No template selected.");
         return QString();
     }
