@@ -60,22 +60,22 @@
 #include <ui4_p.h>
 
 #include <QtCore/qdebug.h>
-#include <QtCore/QDataStream>
-#include <QtWidgets/QAction>
-#include <QtWidgets/QActionGroup>
-#include <QtWidgets/QApplication>
-#include <QtCore/QDir>
-#include <QtCore/QLibraryInfo>
-#include <QtWidgets/QLayout>
-#include <QtWidgets/QWidget>
-#include <QtCore/QMap>
-#include <QtWidgets/QTabWidget>
-#include <QtWidgets/QTreeWidget>
-#include <QtWidgets/QListWidget>
-#include <QtWidgets/QTableWidget>
-#include <QtWidgets/QToolBox>
-#include <QtWidgets/QComboBox>
-#include <QtWidgets/QFontComboBox>
+#include <QtCore/qdatastream.h>
+#include <QtWidgets/qaction.h>
+#include <QtWidgets/qactiongroup.h>
+#include <QtWidgets/qapplication.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qlibraryinfo.h>
+#include <QtWidgets/qlayout.h>
+#include <QtWidgets/qwidget.h>
+#include <QtCore/qmap.h>
+#include <QtWidgets/qtabwidget.h>
+#include <QtWidgets/qtreewidget.h>
+#include <QtWidgets/qlistwidget.h>
+#include <QtWidgets/qtablewidget.h>
+#include <QtWidgets/qtoolbox.h>
+#include <QtWidgets/qcombobox.h>
+#include <QtWidgets/qfontcombobox.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -119,9 +119,6 @@ public:
     explicit TranslatingTextBuilder(bool idBased, bool trEnabled, const QByteArray &className) :
         m_idBased(idBased), m_trEnabled(trEnabled), m_className(className) {}
 
-    TranslatingTextBuilder(bool trEnabled, const QByteArray &className) :
-        m_trEnabled(trEnabled), m_className(className) {}
-
     QVariant loadText(const DomProperty *icon) const override;
 
     QVariant toNativeValue(const QVariant &value) const override;
@@ -169,13 +166,13 @@ QVariant TranslatingTextBuilder::toNativeValue(const QVariant &value) const
 // This is "exported" to linguist
 const QUiItemRolePair qUiItemRoles[] = {
     { Qt::DisplayRole, Qt::DisplayPropertyRole },
-#ifndef QT_NO_TOOLTIP
+#if QT_CONFIG(tooltip)
     { Qt::ToolTipRole, Qt::ToolTipPropertyRole },
 #endif
-#ifndef QT_NO_STATUSTIP
+#if QT_CONFIG(statustip)
     { Qt::StatusTipRole, Qt::StatusTipPropertyRole },
 #endif
-#ifndef QT_NO_WHATSTHIS
+#if QT_CONFIG(whatsthis)
     { Qt::WhatsThisRole, Qt::WhatsThisPropertyRole },
 #endif
     { -1 , -1 }
@@ -242,10 +239,10 @@ public:
     {
     }
 
-    virtual bool eventFilter(QObject *o, QEvent *event)
+    bool eventFilter(QObject *o, QEvent *event) override
     {
         if (event->type() == QEvent::LanguageChange) {
-            const QList<QByteArray> &dynamicPropertyNames = o->dynamicPropertyNames();
+            const auto &dynamicPropertyNames = o->dynamicPropertyNames();
             for (const QByteArray &prop : dynamicPropertyNames) {
                 if (prop.startsWith(PROP_GENERIC_PREFIX)) {
                     const QByteArray propName = prop.mid(sizeof(PROP_GENERIC_PREFIX) - 1);
@@ -255,26 +252,26 @@ public:
                 }
             }
             if (0) {
-#ifndef QT_NO_TABWIDGET
+#if QT_CONFIG(tabwidget)
             } else if (QTabWidget *tabw = qobject_cast<QTabWidget*>(o)) {
                 const int cnt = tabw->count();
                 for (int i = 0; i < cnt; ++i) {
                     RETRANSLATE_SUBWIDGET_PROP(tabw, setTabText, PROP_TABPAGETEXT);
-# ifndef QT_NO_TOOLTIP
+#if QT_CONFIG(tooltip)
                     RETRANSLATE_SUBWIDGET_PROP(tabw, setTabToolTip, PROP_TABPAGETOOLTIP);
 # endif
-# ifndef QT_NO_WHATSTHIS
+#if QT_CONFIG(whatsthis)
                     RETRANSLATE_SUBWIDGET_PROP(tabw, setTabWhatsThis, PROP_TABPAGEWHATSTHIS);
 # endif
                 }
 #endif
-#ifndef QT_NO_LISTWIDGET
+#if QT_CONFIG(listwidget)
             } else if (QListWidget *listw = qobject_cast<QListWidget*>(o)) {
                 const int cnt = listw->count();
                 for (int i = 0; i < cnt; ++i)
                     reTranslateWidgetItem(listw->item(i), m_className, m_idBased);
 #endif
-#ifndef QT_NO_TREEWIDGET
+#if QT_CONFIG(treewidget)
             } else if (QTreeWidget *treew = qobject_cast<QTreeWidget*>(o)) {
                 if (QTreeWidgetItem *item = treew->headerItem())
                     recursiveReTranslate(item, m_className, m_idBased);
@@ -284,7 +281,7 @@ public:
                     recursiveReTranslate(item, m_className, m_idBased);
                 }
 #endif
-#ifndef QT_NO_TABLEWIDGET
+#if QT_CONFIG(tablewidget)
             } else if (QTableWidget *tablew = qobject_cast<QTableWidget*>(o)) {
                 const int row_cnt = tablew->rowCount();
                 const int col_cnt = tablew->columnCount();
@@ -296,7 +293,7 @@ public:
                         reTranslateTableItem(tablew->item(i, j), m_className, m_idBased);
                 }
 #endif
-#ifndef QT_NO_COMBOBOX
+#if QT_CONFIG(combobox)
             } else if (QComboBox *combow = qobject_cast<QComboBox*>(o)) {
                 if (!qobject_cast<QFontComboBox*>(o)) {
                     const int cnt = combow->count();
@@ -309,12 +306,12 @@ public:
                     }
                 }
 #endif
-#ifndef QT_NO_TOOLBOX
+#if QT_CONFIG(toolbox)
             } else if (QToolBox *toolw = qobject_cast<QToolBox*>(o)) {
                 const int cnt = toolw->count();
                 for (int i = 0; i < cnt; ++i) {
                     RETRANSLATE_SUBWIDGET_PROP(toolw, setItemText, PROP_TOOLITEMTEXT);
-# ifndef QT_NO_TOOLTIP
+#if QT_CONFIG(tooltip)
                     RETRANSLATE_SUBWIDGET_PROP(toolw, setItemToolTip, PROP_TOOLITEMTOOLTIP);
 # endif
                 }
@@ -333,16 +330,15 @@ class FormBuilderPrivate: public QFormBuilder
 {
     friend class QT_PREPEND_NAMESPACE(QUiLoader);
     friend class QT_PREPEND_NAMESPACE(QUiLoaderPrivate);
-    typedef QFormBuilder ParentClass;
+    using ParentClass = QFormBuilder;
 
 public:
-    QUiLoader *loader;
+    QUiLoader *loader = nullptr;
 
-    bool dynamicTr;
-    bool trEnabled;
+    bool dynamicTr = false;
+    bool trEnabled = true;
 
-    FormBuilderPrivate(): loader(nullptr), dynamicTr(false), trEnabled(true),
-        m_trwatch(nullptr), m_idBased(false) {}
+    FormBuilderPrivate() = default;
 
     QWidget *defaultCreateWidget(const QString &className, QWidget *parent, const QString &name)
     {
@@ -371,7 +367,7 @@ public:
             return widget;
         }
 
-        return 0;
+        return nullptr;
     }
 
     QLayout *createLayout(const QString &className, QObject *parent, const QString &name) override
@@ -381,7 +377,7 @@ public:
             return layout;
         }
 
-        return 0;
+        return nullptr;
     }
 
     QActionGroup *createActionGroup(QObject *parent, const QString &name) override
@@ -391,7 +387,7 @@ public:
             return actionGroup;
         }
 
-        return 0;
+        return nullptr;
     }
 
     QAction *createAction(QObject *parent, const QString &name)  override
@@ -401,7 +397,7 @@ public:
             return action;
         }
 
-        return 0;
+        return nullptr;
     }
 
     void applyProperties(QObject *o, const QList<DomProperty*> &properties) override;
@@ -411,8 +407,8 @@ public:
 
 private:
     QByteArray m_class;
-    TranslationWatcher *m_trwatch;
-    bool m_idBased;
+    TranslationWatcher *m_trwatch = nullptr;
+    bool m_idBased = false;
 };
 
 static QString convertTranslatable(const DomProperty *p, const QByteArray &className,
@@ -442,7 +438,7 @@ void FormBuilderPrivate::applyProperties(QObject *o, const QList<DomProperty*> &
     if (!m_trwatch)
         m_trwatch = new TranslationWatcher(o, m_class, m_idBased);
 
-    if (properties.empty())
+    if (properties.isEmpty())
         return;
 
     // Unlike string item roles, string properties are not loaded via the textBuilder
@@ -469,7 +465,7 @@ void FormBuilderPrivate::applyProperties(QObject *o, const QList<DomProperty*> &
 QWidget *FormBuilderPrivate::create(DomUI *ui, QWidget *parentWidget)
 {
     m_class = ui->elementClass().toUtf8();
-    m_trwatch = 0;
+    m_trwatch = nullptr;
     m_idBased = ui->attributeIdbasedtr();
     setTextBuilder(new TranslatingTextBuilder(m_idBased, trEnabled, m_class));
     return QFormBuilder::create(ui, parentWidget);
@@ -478,28 +474,28 @@ QWidget *FormBuilderPrivate::create(DomUI *ui, QWidget *parentWidget)
 QWidget *FormBuilderPrivate::create(DomWidget *ui_widget, QWidget *parentWidget)
 {
     QWidget *w = QFormBuilder::create(ui_widget, parentWidget);
-    if (w == 0)
-        return 0;
+    if (w == nullptr)
+        return nullptr;
 
     if (0) {
-#ifndef QT_NO_TABWIDGET
+#if QT_CONFIG(tabwidget)
     } else if (qobject_cast<QTabWidget*>(w)) {
 #endif
-#ifndef QT_NO_LISTWIDGET
+#if QT_CONFIG(listwidget)
     } else if (qobject_cast<QListWidget*>(w)) {
 #endif
-#ifndef QT_NO_TREEWIDGET
+#if QT_CONFIG(treewidget)
     } else if (qobject_cast<QTreeWidget*>(w)) {
 #endif
-#ifndef QT_NO_TABLEWIDGET
+#if QT_CONFIG(tablewidget)
     } else if (qobject_cast<QTableWidget*>(w)) {
 #endif
-#ifndef QT_NO_COMBOBOX
+#if QT_CONFIG(combobox)
     } else if (qobject_cast<QComboBox*>(w)) {
         if (qobject_cast<QFontComboBox*>(w))
             return w;
 #endif
-#ifndef QT_NO_TOOLBOX
+#if QT_CONFIG(toolbox)
     } else if (qobject_cast<QToolBox*>(w)) {
 #endif
     } else {
@@ -525,7 +521,7 @@ QWidget *FormBuilderPrivate::create(DomWidget *ui_widget, QWidget *parentWidget)
 
 bool FormBuilderPrivate::addItem(DomWidget *ui_widget, QWidget *widget, QWidget *parentWidget)
 {
-    if (parentWidget == 0)
+    if (parentWidget == nullptr)
         return true;
 
     if (!ParentClass::addItem(ui_widget, widget, parentWidget))
@@ -539,24 +535,24 @@ bool FormBuilderPrivate::addItem(DomWidget *ui_widget, QWidget *widget, QWidget
     const QFormBuilderStrings &strings = QFormBuilderStrings::instance();
 
     if (0) {
-#ifndef QT_NO_TABWIDGET
+#if QT_CONFIG(tabwidget)
     } else if (QTabWidget *tabWidget = qobject_cast<QTabWidget*>(parentWidget)) {
         const DomPropertyHash attributes = propertyMap(ui_widget->elementAttribute());
         const int i = tabWidget->count() - 1;
         TRANSLATE_SUBWIDGET_PROP(tabWidget, titleAttribute, setTabText, PROP_TABPAGETEXT);
-# ifndef QT_NO_TOOLTIP
+#if QT_CONFIG(tooltip)
         TRANSLATE_SUBWIDGET_PROP(tabWidget, toolTipAttribute, setTabToolTip, PROP_TABPAGETOOLTIP);
 # endif
-# ifndef QT_NO_WHATSTHIS
+#if QT_CONFIG(whatsthis)
         TRANSLATE_SUBWIDGET_PROP(tabWidget, whatsThisAttribute, setTabWhatsThis, PROP_TABPAGEWHATSTHIS);
 # endif
 #endif
-#ifndef QT_NO_TOOLBOX
+#if QT_CONFIG(toolbox)
     } else if (QToolBox *toolBox = qobject_cast<QToolBox*>(parentWidget)) {
         const DomPropertyHash attributes = propertyMap(ui_widget->elementAttribute());
         const int i = toolBox->count() - 1;
         TRANSLATE_SUBWIDGET_PROP(toolBox, labelAttribute, setItemText, PROP_TOOLITEMTEXT);
-# ifndef QT_NO_TOOLTIP
+#if QT_CONFIG(tooltip)
         TRANSLATE_SUBWIDGET_PROP(toolBox, toolTipAttribute, setItemToolTip, PROP_TOOLITEMTOOLTIP);
 # endif
 #endif
@@ -685,9 +681,7 @@ QUiLoader::QUiLoader(QObject *parent)
 /*!
     Destroys the loader.
 */
-QUiLoader::~QUiLoader()
-{
-}
+QUiLoader::~QUiLoader() = default;
 
 /*!
     Loads a form from the given \a device and creates a new widget with the
