@@ -39,6 +39,7 @@
 #include <private/qqmljslexer_p.h>
 #include <private/qqmljsastvisitor_p.h>
 #include <private/qqmljsast_p.h>
+#include <private/qqmlapiversion_p.h>
 
 #include <QCoreApplication>
 #include <QFile>
@@ -52,9 +53,11 @@
 
 QT_BEGIN_NAMESPACE
 
-class LU {
-    Q_DECLARE_TR_FUNCTIONS(LUpdate)
-};
+#if Q_QML_PRIVATE_API_VERSION < 8
+namespace QQmlJS {
+    using SourceLocation = AST::SourceLocation;
+}
+#endif
 
 using namespace QQmlJS;
 
@@ -112,6 +115,10 @@ protected:
                     yyMsg(identLineNo) << qPrintable(LU::tr("%1() requires at least one argument.\n").arg(name));
                     return;
                 }
+                if (AST::cast<AST::TemplateLiteral *>(node->arguments->expression)) {
+                    yyMsg(identLineNo) << qPrintable(LU::tr("%1() cannot be used with template literals. Ignoring\n").arg(name));
+                    return;
+                }
 
                 QString source;
                 if (!createString(node->arguments->expression, &source))
@@ -130,11 +137,11 @@ protected:
                 if (!sourcetext.isEmpty())
                     yyMsg(identLineNo) << qPrintable(LU::tr("//% cannot be used with %1(). Ignoring\n").arg(name));
 
-                TranslatorMessage msg(m_component, source,
+                TranslatorMessage msg(m_component, ParserTool::transcode(source),
                     comment, QString(), m_fileName,
                     node->firstSourceLocation().startLine, QStringList(),
                     TranslatorMessage::Unfinished, plural);
-                msg.setExtraComment(extracomment.simplified());
+                msg.setExtraComment(ParserTool::transcode(extracomment.simplified()));
                 msg.setId(msgid);
                 msg.setExtras(extra);
                 m_translator->extend(msg, m_cd);
@@ -171,11 +178,11 @@ protected:
                         plural = true;
                 }
 
-                TranslatorMessage msg(context, source,
+                TranslatorMessage msg(context, ParserTool::transcode(source),
                     comment, QString(), m_fileName,
                     node->firstSourceLocation().startLine, QStringList(),
                     TranslatorMessage::Unfinished, plural);
-                msg.setExtraComment(extracomment.simplified());
+                msg.setExtraComment(ParserTool::transcode(extracomment.simplified()));
                 msg.setId(msgid);
                 msg.setExtras(extra);
                 m_translator->extend(msg, m_cd);
@@ -199,11 +206,11 @@ protected:
 
                 bool plural = node->arguments->next;
 
-                TranslatorMessage msg(QString(), sourcetext,
+                TranslatorMessage msg(QString(), ParserTool::transcode(sourcetext),
                     QString(), QString(), m_fileName,
                     node->firstSourceLocation().startLine, QStringList(),
                     TranslatorMessage::Unfinished, plural);
-                msg.setExtraComment(extracomment.simplified());
+                msg.setExtraComment(ParserTool::transcode(extracomment.simplified()));
                 msg.setId(id);
                 msg.setExtras(extra);
                 m_translator->extend(msg, m_cd);
@@ -221,8 +228,15 @@ private:
         return std::cerr << qPrintable(m_fileName) << ':' << line << ": ";
     }
 
+    void throwRecursionDepthError() final
+    {
+        std::cerr << qPrintable(m_fileName) << ": "
+                  << qPrintable(LU::tr("Maximum statement or expression depth exceeded"));
+    }
+
+
     void processComments(quint32 offset, bool flush = false);
-    void processComment(const AST::SourceLocation &loc);
+    void processComment(const SourceLocation &loc);
     void consumeComment();
 
     bool createString(AST::ExpressionNode *ast, QString *out)
@@ -252,7 +266,7 @@ private:
     TranslatorMessage::ExtraData extra;
     QString sourcetext;
     QString trcontext;
-    QList<AST::SourceLocation> m_todo;
+    QList<SourceLocation> m_todo;
 };
 
 QString createErrorString(const QString &filename, const QString &code, Parser &parser)
@@ -267,28 +281,23 @@ QString createErrorString(const QString &filename, const QString &code, Parser &
         if (m.isWarning())
             continue;
 
-        QString error = filename + QLatin1Char(':') + QString::number(m.loc.startLine)
-                        + QLatin1Char(':') + QString::number(m.loc.startColumn) + QLatin1String(": error: ")
-                        + m.message + QLatin1Char('\n');
-
-        int line = 0;
-        if (m.loc.startLine > 0)
-            line = m.loc.startLine - 1;
-
-        const QString textLine = lines.at(line);
+#if Q_QML_PRIVATE_API_VERSION >= 8
+        const int line = m.loc.startLine;
+        const int column = m.loc.startColumn;
+#else
+        const int line = m.line;
+        const int column = m.column;
+#endif
+        QString error = filename + QLatin1Char(':')
+                        + QString::number(line) + QLatin1Char(':') + QString::number(column)
+                        + QLatin1String(": error: ") + m.message + QLatin1Char('\n');
 
+        const QString textLine = lines.at(line > 0 ? line - 1 : 0);
         error += textLine + QLatin1Char('\n');
-
-        int column = m.loc.startColumn - 1;
-        if (column < 0)
-            column = 0;
-
-        column = qMin(column, textLine.length());
-
-        for (int i = 0; i < column; ++i) {
+        for (int i = 0, end = qMin(column > 0 ? column - 1 : 0, textLine.length()); i < end; ++i) {
             const QChar ch = textLine.at(i);
             if (ch.isSpace())
-                error += ch.unicode();
+                error += ch;
             else
                 error += QLatin1Char(' ');
         }
@@ -313,7 +322,7 @@ void FindTrCalls::postVisit(AST::Node *node)
 void FindTrCalls::processComments(quint32 offset, bool flush)
 {
     for (; !m_todo.isEmpty(); m_todo.removeFirst()) {
-        AST::SourceLocation loc = m_todo.first();
+        SourceLocation loc = m_todo.first();
         if (! flush && (loc.begin() >= offset))
             break;
 
@@ -330,7 +339,7 @@ void FindTrCalls::consumeComment()
     sourcetext.clear();
 }
 
-void FindTrCalls::processComment(const AST::SourceLocation &loc)
+void FindTrCalls::processComment(const SourceLocation &loc)
 {
     if (!loc.length)
         return;
